@@ -8,7 +8,7 @@
 #   The Artistic License 2.0 (GPL Compatible)
 #
 package Redis;
-$Redis::VERSION = '1.981';
+$Redis::VERSION = '1.982';
 # ABSTRACT: Perl binding for Redis database
 # VERSION
 # AUTHORITY
@@ -685,7 +685,7 @@ sub __send_command {
   my $deb  = $self->{debug};
 
   # if already connected but after a fork, reconnect
-  if ($self->{sock} && ($self->{pid} // 0) != $$) {
+  if ($self->{sock} && ($self->{pid} || 0) != $$) {
     $self->connect;
   }
 
@@ -905,7 +905,7 @@ Redis - Perl binding for Redis database
 
 =head1 VERSION
 
-version 1.981
+version 1.982
 
 =head1 SYNOPSIS
 
